@@ -24,8 +24,8 @@ class TelnetRouterPlugin(PluginBase):
     Basically detects if user was able to connect to a device
     """
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, *arg, **kwargs):
+        super().__init__(*arg, **kwargs)
         self.id = "Telnet"
         self.name = "Telnet"
         self.plugin_version = "0.0.1"
@@ -77,7 +77,7 @@ class TelnetRouterPlugin(PluginBase):
             self._port = count_args[c - 1]
 
 
-def createPlugin():
-    return TelnetRouterPlugin()
+def createPlugin(ignore_info=False):
+    return TelnetRouterPlugin(ignore_info=ignore_info)
+
 
-# I'm Py3
